slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetDS

Obtain the direct solver object associated to the polynomial eigensolver object.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetDS(PEP pep,DS *ds)

Not Collective

### Input Parameters

| pep | - eigensolver context obtained from PEPCreate()

### Output Parameter

| ds | - direct solver context

### See Also

PEPSetDS()

### Level

advanced

### Location

src/pep/interface/pepbasic.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages